<?php

namespace Drupal\bakery\Cookies;

class Gingerbread implements CookieInterface, RemoteCookieInterface {

  /**
   * @var string $name
   */
  private string $name;

  /**
   * @var $or_email
   */
  private $or_email;

  /**
   * @var string $child
   */
  private string $child;

  /**
   * @var int $uid
   */
  private int $uid;

  /**
   * @param string $name
   * @param $or_email //@todo this will not type hint in tests.
   * @param string $child
   * @param int $uid
   */
  final public function __construct(string $name, $or_email, string $child, int $uid) {
    $this->name = $name;
    $this->or_email = $or_email;
    $this->child = $child;
    $this->uid = $uid;
  }

  /**
   * {@inheritDoc}
   */
  public static function fromData(array $data) {
    return new static(
      $data['name'],
      $data['or_email'],
      $data['slave'],
      $data['uid']
    );
  }

  /**
   * {@inheritDoc}
   */
  public function toData(): array {
    return [
      'name' => $this->name,
      'or_email' => $this->or_email,
      // Match slave property are set on the main site.
      'slave' => $this->child,
      'uid' => $this->uid,
    ];
  }

  /**
   * {@inheritDoc}
   */
  public static function getName(): string {
    return 'gingerbread';
  }

  /**
   * {@inheritDoc}
   */
  public function getPath() : string{
    return 'bakery/create';
  }

  /**
   * @return string
   */
  public function getAccountName(): string {
    return $this->name;
  }

  /**
   * @return bool
   */
  public function getOrEmail(): bool {
    return $this->or_email;
  }

  /**
   * @return string
   */
  public function getChild(): string {
    return $this->child;
  }

  /**
   * @return int
   */
  public function getChildUid(): int {
    return $this->uid;
  }

}
