<?php

namespace Drupal\Tests\bakery\Functional;

use Drupal\bakery\Cookies\CookieInterface;
use Drupal\Tests\BrowserTestBase;
use Symfony\Component\BrowserKit\Cookie;

/**
 * @group bakery
 */
class BakerySiteTestBase extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  protected static $modules = ['bakery'];

  private $domain;

  public function setUp(): void {
    parent::setUp();
    $domain = preg_replace('/^[^.]+/', '', rtrim($this->baseUrl, '/'));
    $this->domain = preg_replace('/:\d+$/', '', $domain);
    $this->config('bakery.settings')
      ->set('bakery_key', 'asdf')
      ->set('bakery_domain', $this->domain)
      // An invalid url so tests don't accidentally hammer D.O bakery resources.
      ->set('bakery_parent', 'https://example.com/')
      ->save();
  }

  /**
   * Helper method to bake a cookie on to the "browser" session.
   *
   * @param \Drupal\bakery\Cookies\CookieInterface $cookie
   */
  protected function bakeCookie(CookieInterface $cookie) {
    $this->setCookie($cookie::getName(), $this->container->get('bakery.kitchen')->bakeData($cookie));
  }

  protected function eatCookie(string $name) {
    $this->setCookie($name);
  }

  protected function assertCookieTastesGood(string $cookie, string $name = NULL) {
    $this->assertTrue((bool) $this->container->get('bakery.kitchen')->tasteData($cookie, $name));
  }

  private function setCookie($name, $value = NULL) {
    $jar = $this->getClient()->getCookieJar();
    if ($value === NULL) {
      $jar->expire($name, '/', $this->domain);
      return;
    }
    $jar->set(new Cookie($name, $value, NULL, '/', $this->domain));
  }

  /**
   * @return \Symfony\Component\BrowserKit\AbstractBrowser
   */
  private function getClient() {
    return $this->getSession()->getDriver()->getClient();
  }

  /**
   * Function that can be called during testing.
   *
   * @param $variable
   * @param string $description
   *
   * @return void
   */
  protected function logCatcher($variable, string $description = ''):void {
    $tmp_file = '/tmp/php_test.log';
    $output = '';
    if(!is_null($description)) {
      $output = $description . ': ';
    }

    $output .= print_r($variable, 1) . PHP_EOL;
    file_put_contents($tmp_file, $output, FILE_APPEND);
  }

}
